* Franchino, Fabio, Mark A. Kayser, and Christopher Wratil (2021) `Electoral Competitiveness and Responsiveness: Rational Anticipation in the EU Council' Journal of European Public Policy.

//The following analyses were carried out using STATA/IC 15.1

//This script performs the main analyses reported in the article and the Online Appendix

//Set working directory
cd "YOUR DIRECTORY"



//////////////////
//Merge datasets
//////////////////

//Import electoral competitiveness measures
import delimited "./deu_competitiveness.csv", clear 

//Rename variables
rename deuissuenumber n_issue 
rename deuproposalnumber n_proposal
rename cabinet cabinet_name
rename country government
gen proposal_date = date(dateofproposal, "MDY")
format %d proposal_date

//Keep variables that are needed
keep cabinet_name n_issue n_proposal government fkw3expdurat plpr proposal_date caretaker

//Create encoded country variable
gen country = .
replace country = 1 if government == "be"
replace country = 2 if government == "bu"
replace country = 3 if government == "cz"
replace country = 4 if government == "dk"
replace country = 5 if government == "de"
replace country = 6 if government == "ee"
replace country = 7 if government == "ie"
replace country = 8 if government == "el"
replace country = 9 if government == "es"
replace country = 10 if government == "fr"
replace country = 11 if government == "hr"
replace country = 12 if government == "it"
replace country = 13 if government == "cy"
replace country = 14 if government == "lv"
replace country = 15 if government == "lt"
replace country = 16 if government == "lu"
replace country = 17 if government == "hu"
replace country = 18 if government == "mt"
replace country = 19 if government == "nl"
replace country = 20 if government == "at"
replace country = 21 if government == "pl"
replace country = 22 if government == "pt"
replace country = 23 if government == "ro"
replace country = 24 if government == "si"
replace country = 25 if government == "sk"
replace country = 26 if government == "fi"
replace country = 27 if government == "se"
replace country = 28 if government == "uk"

//Save
save "deu_competitiveness.dta", replace


//Merge CMP-ParlGov party positions
gen date = proposal_date
sort country date
merge m:1 country date using "./Covariates/parties_cmp2019_online_2.1_JEPP.dta", update replace
drop if _merge == 2
drop _merge

//Merge Eurobarometer public opinion
gen nation = government
gen start_date = date
sort nation start_date
merge m:1 nation start_date using "./Covariates/eb_responsiveness_2019_online.dta"
drop if _merge == 2
drop _merge nation start_date

//Merge economic data from Eurostat
gen year = year(proposal_date)
replace government = "bg" if government == "bu"
sort government year
merge m:1 government year using "./Covariates/eu_budget_contributions_2018.dta"
drop if _merge == 2
drop _merge

merge m:1 government year using "./Covariates/eurostat_unemployment_rate_2019.dta"
drop if _merge == 2
drop _merge

merge m:1 government year using "./Covariates/eurostat_inflation_hicp_2019.dta"
drop if _merge == 2
drop _merge
replace government = "bu" if government == "bg"

//Merge electoral proximity data
sort country date
merge m:1 country date using "./Covariates/electoral_proximity2020.dta"
drop if _merge == 2
drop _merge date

//Merge economic freedom data
sort government year
merge m:1 government year using "./Covariates/regulation_data.dta"
drop if _merge == 2
drop _merge

//Merge reclassified DEU dataset with left-right / pro-anti integration positions
sort n_issue government
merge 1:1 n_issue government using "deuIII_classified.dta"
drop _merge

//Label values for primary coding category
label define prim_cat 1 "1: Consumer Protection versus Freedom of Businesses" 2 "2: Environmental Protection versus Freedom of Businesses" 3 "3: Economic Regulation versus Freedom of Businesses" 4 "4: Employees’ Rights versus Other Interests" 5 "5: Protectionism versus Free Trade" 6 "6: Equality versus Acceptance of Inequality" 7 "7: Immigration versus Fortress Europe" 8 "8: Civil and Human Rights versus Fight against Crime" 9 "9: Harmonisation versus National Standards" 10 "10: Wide versus Narrow Scope" 11 "11: EU versus Member State Authority" 12 "12: Speeding Up versus Blocking of EU Legislation" 13 "13: UNCLASSIFIED"
label values prim_cat prim_cat

//Drop where position or rescaled position is missing
drop if position == .
drop if lr_position == . & int_position == .

//Create DEU dataset indicator
gen deu = 1
replace deu = 2 if proposal_date > date("01/01/2001", "DMY")
replace deu = 3 if proposal_date > date("01/01/2010", "DMY")

//Create indicator for countries in which the PMO is leading in EU policy coordination (Jensen 2014)
gen pmo = 0
replace pmo = 1 if government == "bu"
replace pmo = 1 if government == "cz"
replace pmo = 1 if government == "ee"
replace pmo = 1 if government == "fi"
replace pmo = 1 if government == "fr"
replace pmo = 1 if government == "mt"
replace pmo = 1 if government == "uk"

//Label variables
label variable cabinet_name "Name of cabinet"
label variable n_issue "Number of DEU issue"
label variable n_proposal "Number of DEU proposal"
label variable government "Country abbreviation"
label variable fkw3expdurat "Expected duration"
label variable plpr "Plurality loss probabiliy"
label variable caretaker "Caretaker government"
label variable proposal_date "Date when proposal was submitted to Council"
label variable year "Year when proposal was submitted to Council"
label variable deu "Number of DEU dataset"
label variable pmo "Binary indicator whether PMO is leading (Jensen 2014)"
label variable eu_cont_gdp "Receipts from EU budget (%GDP)"
label variable unemployment "Unemployment rate"
label variable inflation "Inflation rate"

//Save
save "main_data_competitiveness.dta", replace



/////////////////
//Main Analyses
/////////////////

//Identify sample: issues where more than 2/3 of government positions are missing are excluded as well as observations where plurality party is not in government
gen lr = 1 if lr_position != .
gen eu = 1 if int_position != .
egen sum_lr = sum(lr), by(n_issue)
egen sum_int = sum(eu), by(n_issue)

gen sample_lr = 1
replace sample_lr = 0 if lr_position == .
replace sample_lr = 0 if ((sum_lr < 9 & proposal_date < date("01/07/2013", "DMY") & deu == 3) | (sum_lr < 10 & proposal_date >= date("01/07/2013", "DMY") & deu == 3) | (sum_lr < 9 & deu == 2) | (sum_lr < 5 & deu == 1)) 
tab plurality_in_gov if sample_lr == 1 //Fraction of plurality parties not in government
replace sample_lr = 0 if plurality_in_gov != 1

//Relabel and rescale variables for table
replace fkw3expdurat = fkw3expdurat / 100
replace distance_elect_planned = distance_elect_planned / 100
label variable fkw3expdurat "Expected duration"
label variable lrs_lag6m "Public opinion"
label variable gov_lr_cmp_static "Government parties' position"
label variable unemployment "Unemployment rate"
label variable inflation "Inflation rate"
label variable plpr "PLPR"
label variable lr_position "Government position"
label variable distance_elect_planned "Days to election"
label variable regul_strength "Economic freedom"
label variable eu_cont_gdp "Net receipts from EU budget"

//Main regression models reported in Table 1 in the article
xtset n_issue
eststo clear
eststo: xtreg lr_position c.fkw3expdurat##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
eststo: xtreg lr_position c.distance_elect_planned##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
gen main_sample = e(sample)
esttab using "./Tables & Figures/Table_1.tex", b(3) noomitted label replace se booktabs alignment(D{.}{.}{-1}) title(Models of governments' left-right positions in the Council\label{tab1}) star(* 0.05 ** 0.01)

//Plot PLPR effect - Figure 1 in the article
sum plpr if e(sample) == 1, detail
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram plpr if e(sample) == 1 & plpr >= 0.03 & plpr <= 0.40, bin(30) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col23, yaxis(2) yscale(axis(2) alt noline) ytitle("Number of observations") ytitle("Marginal effect of {it:public opinion}", axis(2)) lpattern(solid)) (line ll col23, yaxis(2) lpattern(dash)) (line ul col23, yaxis(2) lpattern(dash)) (function y=0, range(0.03 0.40) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("Plurality {it:loss probability}") xscale(range(0.03 0.40) noextend) xlabel(0.05 (0.05) 0.40)  yscale(noline) xscale(noline)
graph export "./Tables & Figures/Figure_1.png", replace height(2000)
drop b se z pvalue ll ul df crit eform col2*

tab main_sample if plpr >= .12 & plpr <= .29 //number of observations with significant effects
dis 982/3225

//Test for difference of effects
lincom (lrs_lag6m + 0.02 * c.plpr#c.lrs_lag6m + 0.02*0.02* c.plpr#c.plpr#c.lrs_lag6) - (lrs_lag6m + 0.15 * c.plpr#c.lrs_lag6m + 0.15*0.15* c.plpr#c.plpr#c.lrs_lag6m)
lincom (lrs_lag6m + 0.07 * c.plpr#c.lrs_lag6m + 0.07*0.07* c.plpr#c.plpr#c.lrs_lag6) - (lrs_lag6m + 0.18 * c.plpr#c.lrs_lag6m + 0.18*0.18* c.plpr#c.plpr#c.lrs_lag6m)


//Four-way interaction with dummy whether plurality party is powerful
gen pl_power = 0
label variable pl_power "Binary indicator for powerful plurality party"
replace pl_power = 1 if pm_seat_share >= 0.8
replace pl_power = 1 if pmo == 1
replace pl_power = 0 if pm_is_plurality == 0

//Regression analysis reported in Table A5 in the Online Appendix
eststo clear
eststo: xtreg lr_position pl_power##c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
esttab using "./Tables & Figures/Table_A5.tex", b(3) noomitted label replace se booktabs alignment(D{.}{.}{-1}) title(Four-way interaction model of governments' left-right positions\label{tab2}) drop(gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength) star(* 0.05 ** 0.01)

//Plot PLPR effect if plurality party is powerful
sum plpr if sample == 1 & pl_power == 1, detail
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40) pl_power = 1)
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram plpr if e(sample) == 1 & plpr >= 0.03 & plpr <= 0.40 & pl_power == 1, bin(30) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col23, yaxis(2) yscale(axis(2) alt noline) ytitle("Number of observations") ytitle("Marginal effect of {it:public opinion}", axis(2)) lpattern(solid)) (line ll col23, yaxis(2) lpattern(dash)) (line ul col23, yaxis(2) lpattern(dash)) (function y=0, range(0.03 0.40) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("") xscale(range(0.03 0.40) noextend) xlabel(0.05 (0.05) 0.40)  yscale(noline) xscale(noline) title("{bf:Plurality party powerful}")
graph save "./Tables & Figures/PLPR_pl_powerful.gph", replace 
drop b se z pvalue ll ul df crit eform col2*

//Plot PLPR effect if plurality party is not powerful
sum plpr if sample == 1 & pl_power == 0, detail
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.45) pl_power = 0)
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram plpr if e(sample) == 1 & plpr >= 0.03 & plpr <= 0.45 & pl_power == 0, bin(30) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col23, yaxis(2) yscale(axis(2) alt noline) ytitle("Number of observations") ytitle("Marginal effect of {it:public opinion}", axis(2)) lpattern(solid)) (line ll col23, yaxis(2) lpattern(dash)) (line ul col23, yaxis(2) lpattern(dash)) (function y=0, range(0.03 0.45) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("") xscale(range(0.03 0.45) noextend) xlabel(0.05 (0.05) 0.45)  yscale(noline) xscale(noline) title("{bf:Plurality party not powerful}")
graph save "./Tables & Figures/PLPR_pl_not_powerful.gph", replace 
drop b se z pvalue ll ul df crit eform col2*

//Plot Figure 2 in the article
graph combine "./Tables & Figures/PLPR_pl_powerful.gph" "./Tables & Figures/PLPR_pl_not_powerful.gph", ycommon scheme(lean2) altshrink title("") b1title("Plurality {it:loss probability}", size("medsmall"))
graph export "./Tables & Figures/Figure_2.png", replace height(2000)



/////////////////////////////////
//Report descriptive statistics
/////////////////////////////////

//Produce Table A2 in the Online Appendix
gen save = e(sample)
eststo clear
estpost sum lr_position lrs_lag6m fkw3expdurat plpr distance_elect_planned pl_power gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if save == 1
esttab using "./Tables & Figures/Table_A2.tex", replace cells("mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") nomtitle nonumber label

//Produce Table A3 in the Online Appendix
eststo clear
estpost tab country if save == 1, sort
esttab using "./Tables & Figures/Table_A3.tex", replace cells("b pct(fmt(2)) cumpct(fmt(2))") collabels("Obs." "Percent" "cum. Percent") nomtitle nonumber label varlabels(`e(labels)')

//Produce Table A1 in the Online Appendix
eststo clear
estpost tab prim_cat if save == 1
esttab using "./Tables & Figures/Table_A1.tex", replace cells("b pct(fmt(2)) cumpct(fmt(2))") collabels("Obs." "Percent" "cum. Percent") nomtitle nonumber label varlabels(`e(labels)')



/////////////////////
//Robustness checks
/////////////////////

eststo clear

//Issue random effects - Model A1 in Table A6 in the Online Appendix
eststo: xtreg lr_position c.distance_elect_planned##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, re 
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
marginsplot 

//Country fixed effects - Model A2 in Table A6 in the Online Appendix
eststo: xtreg lr_position c.distance_elect_planned##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength i.country if sample == 1, re
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
marginsplot 
//Model below is mentioned in footnote 14 in the Online Appendix 
xtreg lr_position c.distance_elect_planned##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength i.country if sample == 1, fe
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
marginsplot 

//Excluding caretakers - Model A3 in Table A6 in the Online Appendix
eststo: xtreg lr_position c.distance_elect_planned##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1 & caretaker == 0, fe vce(cluster country) nonest dfadj
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
marginsplot 

//Full sample including issues with high missingness - Model A4 in Table A6 in the Online Appendix
eststo: xtreg lr_position c.distance_elect_planned##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if plurality_in_gov == 1, fe vce(cluster country) nonest dfadj
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
marginsplot 

//Binary dependent variable - Model A5 in Table A6 in the Online Appendix
gen lr_binary = .
replace lr_binary = 1 if lr_position >= 50
replace lr_binary = 0 if lr_position < 50
replace lr_binary = . if lr_position == .
tab lr_binary
label variable lr_binary "Left-Right Position of Government (binary)"

eststo: logit lr_binary c.distance_elect_planned##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength i.n_issue if sample == 1
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
marginsplot 

//Split sample - Models A6.1 and A6.2 in Table A6 in the Online Appendix
sum plpr if e(sample) == 1, detail
gen medium_plpr = 0
replace medium_plpr = 1 if plpr > .0708601 & plpr < .2734757
replace medium_plpr = . if plpr == .
eststo: xtreg lr_position lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1 & medium_plpr == 1, fe vce(cluster country) nonest dfadj
eststo: xtreg lr_position lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1 & medium_plpr == 0, fe vce(cluster country) nonest dfadj

//Produce Table A6 in the Online Appendix
esttab using "./Tables & Figures/Table_A6.tex", b(3) noomitted label replace se booktabs alignment(D{.}{.}{-1}) title(Robustness checks\label{robustness_table}) drop(gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength) star(+ 0.10 * 0.05 ** 0.01)
eststo clear


//Use days to elections that really occurred - Model A7 in Table A7 in the Online Appendix
eststo: xtreg lr_position c.distance_elect##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
marginsplot 

//Four-way interaction electoral cycle - Model A8 in Table A7 in the Online Appendix
gen two_years_to_election = .
label variable two_years_to_election "Election <2 years"
replace two_years_to_election = 1 if distance_elect_planned < 7.3 & distance_elect_planned != .
replace two_years_to_election = 0 if distance_elect_planned >= 7.3 & distance_elect_planned != .
eststo: xtreg lr_position c.two_years_to_election##c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40) two_years_to_election = (0 1))
marginsplot, by(two_years_to_election)

//Produce Table A7 in the Online Appendix
esttab using "./Tables & Figures/Table_A7.tex", b(3) noomitted label replace se booktabs alignment(D{.}{.}{-1}) title(Robustness checks\label{robustness_table2}) drop(gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength) star(+ 0.10 * 0.05 ** 0.01)


//Different time lags
eststo: xtreg lr_position c.distance_elect_planned##c.lrs_ipol c.plpr##c.plpr##c.lrs_ipol gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
sum plpr if e(sample) == 1, detail
margins, dydx(lrs_ipol) at(plpr = (0.03 (0.01) 0.40))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram plpr if e(sample) == 1 & plpr >= 0.03 & plpr <= 0.40, bin(30) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col23, yaxis(2) yscale(axis(2) alt noline) ytitle("Number of observations") ytitle("Marginal effect of {it:public opinion}", axis(2)) lpattern(solid)) (line ll col23, yaxis(2) lpattern(dash)) (line ul col23, yaxis(2) lpattern(dash)) (function y=0, range(0.03 0.40) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("Plurality {it:loss probability}") xscale(range(0.03 0.40) noextend) xlabel(0.05 (0.05) 0.40)  yscale(noline) xscale(noline) title("{bf:Current public opinion}")
graph save "./Tables & Figures/time_lags1.gph", replace
drop b se z pvalue ll ul df crit eform col2*

eststo: xtreg lr_position c.distance_elect_planned##c.lrs_lag6m c.plpr##c.plpr##c.lrs_lag6m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
sum plpr if e(sample) == 1, detail
margins, dydx(lrs_lag6m) at(plpr = (0.03 (0.01) 0.40))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram plpr if e(sample) == 1 & plpr >= 0.03 & plpr <= 0.40, bin(30) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col23, yaxis(2) yscale(axis(2) alt noline) ytitle("Number of observations") ytitle("Marginal effect of {it:public opinion}", axis(2)) lpattern(solid)) (line ll col23, yaxis(2) lpattern(dash)) (line ul col23, yaxis(2) lpattern(dash)) (function y=0, range(0.03 0.40) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("Plurality {it:loss probability}") xscale(range(0.03 0.40) noextend) xlabel(0.05 (0.05) 0.40)  yscale(noline) xscale(noline) title("{bf:Six-month lag of public opinion}")
graph save "./Tables & Figures/time_lags2.gph", replace
drop b se z pvalue ll ul df crit eform col2*

eststo: xtreg lr_position c.distance_elect_planned##c.lrs_lag1y c.plpr##c.plpr##c.lrs_lag1y gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
sum plpr if e(sample) == 1, detail
margins, dydx(lrs_lag1y) at(plpr = (0.03 (0.01) 0.40))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram plpr if e(sample) == 1 & plpr >= 0.03 & plpr <= 0.40, bin(30) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col23, yaxis(2) yscale(axis(2) alt noline) ytitle("Number of observations") ytitle("Marginal effect of {it:public opinion}", axis(2)) lpattern(solid)) (line ll col23, yaxis(2) lpattern(dash)) (line ul col23, yaxis(2) lpattern(dash)) (function y=0, range(0.03 0.40) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("Plurality {it:loss probability}") xscale(range(0.03 0.40) noextend) xlabel(0.05 (0.05) 0.40)  yscale(noline) xscale(noline) title("{bf:One-year lag of public opinion}")
graph save "./Tables & Figures/time_lags3.gph", replace
drop b se z pvalue ll ul df crit eform col2*

eststo: xtreg lr_position c.distance_elect_planned##c.lrs_lag18m c.plpr##c.plpr##c.lrs_lag18m gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength if sample == 1, fe vce(cluster country) nonest dfadj
sum plpr if e(sample) == 1, detail
margins, dydx(lrs_lag18m) at(plpr = (0.03 (0.01) 0.40))
mat a = r(table)'
svmat a, name(col)
mat at = r(at)
svmat at, name(col2)
twoway (histogram plpr if e(sample) == 1 & plpr >= 0.03 & plpr <= 0.40, bin(30) scheme(lean2) yaxis(1) yscale(axis(1) alt) legend(off) fcolor(gs12) lcolor(gs12) frequency ylabel(, nogrid)) (line b col23, yaxis(2) yscale(axis(2) alt noline) ytitle("Number of observations") ytitle("Marginal effect of {it:public opinion}", axis(2)) lpattern(solid)) (line ll col23, yaxis(2) lpattern(dash)) (line ul col23, yaxis(2) lpattern(dash)) (function y=0, range(0.03 0.40) lcolor(gs8) lpattern(solid) yaxis(2)), xtitle("Plurality {it:loss probability}") xscale(range(0.03 0.40) noextend) xlabel(0.05 (0.05) 0.40)  yscale(noline) xscale(noline) title("{bf:Eighteen-month lag of public opinion}")
graph save "./Tables & Figures/time_lags4.gph", replace
drop b se z pvalue ll ul df crit eform col2*

//Plot Figure A4 in the Online Appendix
graph combine "./Tables & Figures/time_lags1.gph" "./Tables & Figures/time_lags2.gph" "./Tables & Figures/time_lags3.gph" "./Tables & Figures/time_lags4.gph", scheme(lean2) altshrink row(2) ycommon
graph export "./Tables & Figures/Figure_A4.png", replace height(2000)



//////////////
//Clarke test
//////////////

//Create variables passively
tab n_issue if main_sample == 1, gen(issues)
gen int_distance = distance_elect_planned * lrs_lag6m 
gen int_plpr = plpr * lrs_lag6m
gen plpr_sq = plpr * plpr
gen int_plpr_sq = plpr * plpr * lrs_lag6m
gen int_distance_lead = distance_elect_planned * lrs_lead6m 
gen int_plpr_lead = plpr * lrs_lead6m
gen int_plpr_sq_lead = plpr * plpr * lrs_lead6m
gen int_distance_lead2 = distance_elect_planned * lrs_lead1y 
gen int_plpr_lead2 = plpr * lrs_lead1y
gen int_plpr_sq_lead2 = plpr * plpr * lrs_lead1y


program mynormal_lf
        version 11.1
        args lnf mu lnsigma
        quietly replace `lnf' = ln(normalden($ML_y1,`mu', exp(`lnsigma')))
end

ml model lf  mynormal_lf  (lr_position = lrs_lag6m distance_elect_planned int_distance plpr int_plpr plpr_sq int_plpr_sq gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength issues1-issues192) (lnsigma:)
ml max, nolog
predict double xb_reg
gen double lnf_reg = ln(normalden(lr_position, xb_reg, exp([lnsigma]_b[_cons])))

ml model lf  mynormal_lf  (lr_position = lrs_lead6m distance_elect_planned int_distance_lead plpr int_plpr_lead plpr_sq int_plpr_sq_lead gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength issues1-issues192) (lnsigma:)
ml max, nolog
predict double xb_reg_lead
gen double lnf_reg_lead = ln(normalden(lr_position, xb_reg_lead, exp([lnsigma]_b[_cons])))

ml model lf  mynormal_lf  (lr_position = lrs_lead1y distance_elect_planned int_distance_lead2 plpr int_plpr_lead2 plpr_sq int_plpr_sq_lead2 gov_lr_cmp_static unemployment inflation eu_cont_gdp regul_strength issues1-issues192) (lnsigma:)
ml max, nolog
predict double xb_reg_lead2
gen double lnf_reg_lead2 = ln(normalden(lr_position, xb_reg_lead2, exp([lnsigma]_b[_cons])))

gen diff = lnf_reg - lnf_reg_lead
kdensity diff if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
//Distribution is leptokurtic

gen diff2 = lnf_reg - lnf_reg_lead2
kdensity diff2 if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
//Distribution is leptokurtic

//Produce Clarke test results in Table A8 in the Online Appendix
signtest lnf_reg = lnf_reg_lead if e(sample) == 1
signtest lnf_reg = lnf_reg_lead2 if e(sample) == 1
program drop mynormal_lf
drop lnf* xb* diff



